local L_CALL = "%s looted %s!"
local L_CALL_WITH_SOURCE = "%s looted %s (%s)!"

local ignoredItems = {
	[30316] = true, -- Devastation
	[30317] = true, -- Cosmic Infuser
	[30312] = true, -- Infinity Blade
	[30318] = true, -- Netherstrand Longbow
	[30313] = true, -- Staff of Disintegration
	[30311] = true, -- Warp Slicer
	[30320] = true, -- Bundle of Nether Spikes
	[30314] = true, -- Phaseshift Bulwark
	[30319] = true, -- Nether Spikes
	[29434] = true, -- Badge of Justice
	[22450] = true, -- Void Crystal
	[20725] = true, -- Nexus Crystal

	[32428] = true, -- Heart of Darkness

	[32230] = true, -- Shadowsong Amethyst
	[32249] = true, -- Seaspray Emerald
	[32231] = true, -- Pyrestone
	[32229] = true, -- Lionseye
	[32228] = true, -- Empyrean Sapphire
	[32227] = true, -- Crimson Spinel

	[40752] = true, -- Emblem of Heroism
	[40753] = true, -- Emblem of Valor
	[34057] = true, -- Abyss Crystal
}

local pname = UnitName("player")
local shouldTransmit = true
local f = CreateFrame("Frame")

local C_SELF = (LOOT_ITEM_SELF):gsub("%%s", "(.+)")
local C_LOOT = (LOOT_ITEM):gsub("%%s", "(.+)")
local C_SELF_M = (LOOT_ITEM_SELF_MULTIPLE):gsub("%%sx%%d", "(.+)x(%%d+)")
local C_LOOT_M = (LOOT_ITEM_MULTIPLE):gsub("%%s receives loot: %%sx%%d", "(.+) receives loot: (.+)x(%%d+)")

local candidates = {}
local totalElapsed = 0
local function onUpdate(self, elapsed)
	totalElapsed = totalElapsed + elapsed
	if totalElapsed > 10 then
		self:SetScript("OnUpdate", nil)
		totalElapsed = 0
		if #candidates > 0 then
			table.sort(candidates)
			shouldTransmit = candidates[1] == pname and true or false
			wipe(candidates)
		else
			shouldTransmit = true
		end
	end
end
local function checkGroup()
	f:SetScript("OnUpdate", onUpdate)
	SendAddonMessage("BTC", "ping", "RAID")
end

local function getSource(looter)
	if UnitInRaid("player") then
		for i = 1, GetNumRaidMembers() do
			local u = "raid" .. i .. "target"
			if UnitExists(u) and UnitIsDead(u) and UnitClassification(u) == "worldboss" then
				return UnitName(u)
			end
		end
	else
		local unit = nil
		if GetNumPartyMembers() > 0 then
			for i = 1, 5 do
				local u = "party" .. i
				if UnitName(u) == looter then
					unit = u .. "target"
				end
			end
		else
			unit = "target"
		end
		if UnitExists(unit) and UnitIsDead(unit) and UnitIsEnemy("player", unit) then
			return UnitName(unit)
		end
	end
end

local function notify(msg)
	local player, item, quantity = pname, nil, 1
	if msg:match(C_SELF) then
		item = msg:match(C_SELF)
	elseif msg:match(C_LOOT) then
		player, item = msg:match(C_LOOT)
	elseif msg:match(C_SELF_M) then
		item, quantity = msg:match(C_SELF_M)
	elseif msg:match(C_LOOT_M) then
		player, item, quantity = msg:match(C_LOOT_M)
	end
	if not item or not player then return end
	local n, link, quality = GetItemInfo(item)
	if not quality or quality < 4 then return end
	local itemId = select(3, link:find("item:(%d+):"))
	if not itemId then return end
	itemId = tonumber(itemId:trim())
	if type(itemId) ~= "number" or ignoredItems[itemId] then return end
	local source = getSource(player)
	local m = nil
	if source then
		m = L_CALL_WITH_SOURCE:format(player, link, source)
	else
		m = L_CALL:format(player, link)
	end
	--print(m)
	SendChatMessage(m, "GUILD")
end

f:SetScript("OnEvent", function(self, event, prefix, message, distribution, sender)
	if event == "CHAT_MSG_LOOT" then
		if not shouldTransmit then return end
		notify(prefix)
	elseif event == "CHAT_MSG_ADDON" then
		if prefix ~= "BTC" then return end
		table.insert(candidates, sender)
	else
		checkGroup()
	end
end)

f:RegisterEvent("CHAT_MSG_LOOT")
f:RegisterEvent("CHAT_MSG_ADDON")
f:RegisterEvent("PARTY_MEMBERS_CHANGED")
f:RegisterEvent("RAID_ROSTER_UPDATE")
f:Show()

